-- Install Lazy.nvim
local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
  vim.fn.system({
    "git",
    "clone",
    "--filter=blob:none",
    "https://github.com/folke/lazy.nvim.git",
    "--branch=stable", -- latest stable release
    lazypath,
  })
end
vim.opt.rtp:prepend(lazypath)

require('lazy').setup({
    'mbbill/undotree',
    'nvim-tree/nvim-web-devicons',
    'airblade/vim-rooter',
    "rafamadriz/friendly-snippets",
    'ConradIrwin/vim-bracketed-paste',
    'Vimjas/vim-python-pep8-indent',
    'cappyzawa/trim.nvim',
    'gpanders/editorconfig.nvim',
    'ervandew/supertab',
    'williamboman/mason.nvim',
    'williamboman/mason-lspconfig.nvim',
    'ggandor/leap.nvim',
    'hrsh7th/cmp-buffer',
    'hrsh7th/cmp-cmdline',
    'hrsh7th/cmp-nvim-lsp',
    'hrsh7th/cmp-path',
    'hrsh7th/nvim-cmp',
    'hrsh7th/vim-vsnip',
    'hrsh7th/vim-vsnip-integ',
    "rktjmp/lush.nvim",
    'lervag/vimtex',
    'neovim/nvim-lspconfig',
    'numToStr/Comment.nvim',
    'vimwiki/vimwiki',
    'intrntbrn/awesomewm-vim-tmux-navigator',
    'windwp/nvim-autopairs',
    { 'TimUntersberger/neogit', dependencies = {'nvim-lua/plenary.nvim'} },
    {'nvim-lualine/lualine.nvim', dependencies = { 'nvim-tree/nvim-web-devicons', opt = true }},
    { 'nvim-telescope/telescope-fzf-native.nvim', build = 'cmake -S. -Bbuild -DCMAKE_BUILD_TYPE=Release && cmake --build build --config Release && cmake --install build --prefix build' },
    {'nvim-telescope/telescope.nvim', dependencies = {'nvim-lua/plenary.nvim'}},
    {"nvim-treesitter/nvim-treesitter", build = ":TSUpdate"},
    {"folke/trouble.nvim", dependencies = {"nvim-tree/nvim-web-devicons"}},
    {'nvim-tree/nvim-tree.lua', dependencies = {'nvim-tree/nvim-web-devicons'}, tag = 'nightly'},
    {dir = '~/.config/nvim/colorschemes/material'},
})
